Learn R Programming

CausalFX (version 1.0.1)

print.cfx: Prints a CausalFX Problem Instance

Description

Prints some of the information regarding a cfx object.

Usage

"print"(x, ...)

Arguments

x
a cfx object.
...
other parameters, ignored.

Details

The information that is displayed includes the identifiers of the treatment and outcome variables, the names of all variables and, if a theoretical causal graph is part of the object specification, its causal structured described in terms of the parent ids for each variable.