Learn R Programming

CausalFX (version 1.0.1)

summary.covsearch: Summarize Covariate Search Outputs

Description

summary method for class "covsearch".

Usage

"summary"(object, ...)

Arguments

object
an object of class "covsearch", usually a result of a call to covsearch.
...
other parameters, ignored.

Value

Besides fields inherented from the covsearch object, a list summary statistics is included:
q
an array of 5 entries corresponding to evenly space quantiles of the ACE of the highest scoring witness/admissible set pair.
ci
95% marginal posterior credible interval for the chosen ACE.

See Also

The model fitting function covsearch.