Learn R Programming

CausalFX (version 1.0.1)

summary.wpp: Summarize Witness Protection Program Outputs

Description

summary method for class "wpp".

Usage

"summary"(object, ...)

Arguments

object
an object of class "wpp", usually a result of a call to wpp.
...
other parameters, ignored.

Value

Besides fields inherented from the wpp object, a list summary statistics is included:
lq
an array of 5 entries corresponding to evenly space quantiles of the lower bound of the ACE of the highest scoring witness/admissible set pair.
lci
95% marginal posterior credible interval for the chosen ACE lower bound.
uq
an array of 5 entries corresponding to evenly space quantiles of the lower bound of the ACE of the highest scoring witness/admissible set pair.
uci
95% marginal posterior credible interval for the chosen ACE lower bound.
hscore_bound
score of the witness/admissible oair of highest score.
chosen_w
witness of the witness/admissible pair of highest score.
chosen_Z
admissible set of the witness/admissible set of highest score.
min_l
estimated minimum lower bound of all lower bounds found by the procedure.
max_u
estimated maximum upper bound of all upper bounds found by the procedure.
narrowest_bound
lower and upper bounds corresponding to the narrowest ACE interval found by the procedure.

See Also

The model fitting function wpp.